@@ -15,7 +15,7 @@ from .base import DimensionError, GridBase, _check_shape, discretize_interval
 from .cartesian import CartesianGrid
 
 if TYPE_CHECKING:
-    from .boundaries import Boundaries  # @UnusedImport
+    from .boundaries.axes import Boundaries, BoundariesData  # @UnusedImport
     from .spherical import PolarGrid  # @UnusedImport
 
 
@@ -148,7 +148,7 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
         boundary_distance: float = 0,
         cartesian: bool = True,
         avoid_center: bool = False,
-    ):
+    ) -> np.ndarray:
         """return a random point within the grid
 
         Note that these points will be uniformly distributed on the radial axis,
@@ -186,7 +186,7 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
         else:
             return point
 
-    def get_line_data(self, data, extract: str = "auto") -> Dict[str, Any]:
+    def get_line_data(self, data: np.ndarray, extract: str = "auto") -> Dict[str, Any]:
         """return a line cut along the cylindrical symmetry axis
 
         Args:
@@ -238,7 +238,7 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
             "label_y": label_y,
         }
 
-    def get_image_data(self, data) -> Dict[str, Any]:
+    def get_image_data(self, data: np.ndarray) -> Dict[str, Any]:
         """return a 2d-image of the data
 
         Args:
@@ -258,11 +258,11 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
             "label_y": self.axes[1],
         }
 
-    def contains_point(self, point) -> bool:
+    def contains_point(self, point: np.ndarray) -> bool:
         """check whether the point is contained in the grid
 
         Args:
-            point (vector): Coordinates of the point
+            point (:class:`numpy.ndarray`): Coordinates of the point
         """
         assert len(point) == 3
         r = np.hypot(point[0], point[1])
@@ -270,7 +270,7 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
         return bool(r <= self.radius and bounds_z[0] <= point[2] <= bounds_z[1])
 
     def iter_mirror_points(
-        self, point, with_self: bool = False, only_periodic: bool = True
+        self, point: np.ndarray, with_self: bool = False, only_periodic: bool = True
     ) -> Generator:
         """generates all mirror points corresponding to `point`
 
@@ -300,36 +300,7 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
         r_vols = np.diff(areas).reshape(self.shape[0], 1)
         return (r_vols, dz)
 
-    def normalize_point(self, point, reduced_coords: bool = False):
-        """normalize coordinates by applying periodic boundary conditions
-
-        Args:
-            point (:class:`numpy.ndarray`): Coordinates of a single point
-            reduced_coords (bool): Flag determining whether only the coordinates
-                corresponding to axes in this grid are given
-
-        Returns:
-            :class:`numpy.ndarray`: The respective coordinates with periodic
-            boundary conditions applied.
-        """
-        point = np.asarray(point, dtype=np.double)
-        size = self.num_axes if reduced_coords else self.dim
-        if point.size == 0:
-            return np.zeros((0, size))
-        if point.shape[-1] != size:
-            raise DimensionError(
-                f"Dimension mismatch: Array of shape {point.shape} does not describe "
-                f"points of dimension {size}"
-            )
-
-        if self._periodic_z:
-            z_min = self.axes_bounds[1][0]
-            point[..., -1] = (point[..., -1] - z_min) % self.length + z_min
-            return point
-        else:
-            return point
-
-    def point_to_cartesian(self, points):
+    def point_to_cartesian(self, points: np.ndarray) -> np.ndarray:
         """convert coordinates of a point to Cartesian coordinates
 
         Args:
@@ -340,15 +311,15 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
             :class:`numpy.ndarray`: The Cartesian coordinates of the point
         """
         points = np.atleast_1d(points)
-        if points.shape[-1] != 2:
-            raise DimensionError(f"Dimension mismatch: Points {points} invalid")
+        if points.shape[-1] != self.num_axes:
+            raise DimensionError(f"Array of shape {points.shape} cannot denote points")
 
         x = points[..., 0]
         y = np.zeros_like(x)
         z = points[..., 1]
         return np.stack((x, y, z), axis=-1)
 
-    def point_from_cartesian(self, points):
+    def point_from_cartesian(self, points: np.ndarray) -> np.ndarray:
         """convert points given in Cartesian coordinates to this grid
 
         This function returns points restricted to the x-z plane, i.e., the
@@ -361,12 +332,14 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
         Returns:
             :class:`numpy.ndarray`: Points given in the coordinates of the grid
         """
-        points = self.normalize_point(points)
+        points = np.atleast_1d(points)
+        assert points.shape[-1] == self.dim
+
         rs = np.hypot(points[..., 0], points[..., 1])
         zs = points[..., 2]
         return np.stack((rs, zs), axis=-1)
 
-    def cell_to_point(self, cells, cartesian: bool = True):
+    def cell_to_point(self, cells: np.ndarray, cartesian: bool = True) -> np.ndarray:
         """convert cell coordinates to real coordinates
 
         This function returns points restricted to the x-z plane, i.e., the
@@ -385,10 +358,11 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
             :class:`numpy.ndarray`: The center points of the respective cells
         """
         cells = np.atleast_1d(cells)
+
         if cells.size == 0:
             return np.zeros((0, self.dim))
-        if cells.shape[-1] != 2:
-            raise DimensionError(f"Dimension mismatch: Cell {cells} invalid")
+        if cells.shape[-1] != self.num_axes:
+            raise DimensionError(f"Array of shape {cells.shape} cannot denote cells")
 
         # convert from cells indices to grid coordinates
         points = (cells + 0.5) * self.discretization
@@ -398,7 +372,7 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
         else:
             return points
 
-    def point_to_cell(self, points):
+    def point_to_cell(self, points: np.ndarray) -> np.ndarray:
         """Determine cell(s) corresponding to given point(s)
 
         This function respects periodic boundary conditions, but it does not
@@ -412,12 +386,13 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
             :class:`numpy.ndarray`: The indices of the respective cells
         """
         points = self.point_from_cartesian(points)
+
         # convert from grid coordinates to cells indices
         points[..., 1] -= self.axes_bounds[1][0]
         points /= self.discretization
         return points.astype(np.int)
 
-    def difference_vector_real(self, p1, p2):
+    def difference_vector_real(self, p1: np.ndarray, p2: np.ndarray) -> np.ndarray:
         """return the vector pointing from p1 to p2.
 
         In case of periodic boundary conditions, the shortest vector is returned
@@ -436,11 +411,13 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
             diff[..., 1] = (diff[..., 1] + size / 2) % size - size / 2
         return diff
 
-    def polar_coordinates_real(self, origin, ret_angle: bool = False):
+    def polar_coordinates_real(
+        self, origin: np.ndarray, ret_angle: bool = False
+    ) -> np.ndarray:
         """return spherical coordinates associated with the grid
 
         Args:
-            origin (vector): Coordinates of the origin at which the polar
+            origin (:class:`numpy.ndarray`): Coordinates of the origin at which the polar
                 coordinate system is anchored. Note that this must be of the
                 form `[0, 0, z_val]`, where only `z_val` can be chosen freely.
             ret_angle (bool): Determines whether the azimuthal angle is returned
@@ -465,7 +442,9 @@ class CylindricalGrid(GridBase):  # lgtm [py/missing-equals]
             return dist
 
     @fill_in_docstring
-    def get_boundary_conditions(self, bc="natural", rank: int = 0) -> "Boundaries":
+    def get_boundary_conditions(
+        self, bc: "BoundariesData" = "natural", rank: int = 0
+    ) -> "Boundaries":
         """constructs boundary conditions from a flexible data format
 
         Args:
