@@ -83,7 +83,7 @@ class AllenCahnPDE(PDEBase):
             the evolution rate.
         """
         shape = state.grid.shape
-        arr_type = nb.typeof(np.empty(shape, dtype=np.double))
+        arr_type = nb.typeof(np.empty(shape, dtype=state.data.dtype))
         signature = arr_type(arr_type, nb.double)
 
         interface_width = self.interface_width
